# regulated-bus

> a regulated, 1.25 - 32 VDC, 5A, bus based on [XL4015](./parts/XL4015.md)

|   |   |   |
| --- | --- | --- |
| [![image](https://github.com/kamangir/bluer-designs/blob/main/regulated-bus/wiring.png?raw=true)](https://github.com/kamangir/bluer-designs/blob/main/regulated-bus/wiring.svg) | [![image](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251112_214845.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251112_214845.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_103345.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_103345.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_103404.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_103404.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_103646.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_103646.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_103653.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_103653.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_103659.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_103659.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_103703.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_103703.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_103713.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_103713.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_103722.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_103722.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_104805.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_104805.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_113332.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251113_113332.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251116_234737.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/regulated-bus/20251116_234737.jpg?raw=true) |  |  |

## parts

|   |   |   |   |   |   |   |   |
| --- | --- | --- | --- | --- | --- | --- | --- |
| [`DC power plug, 5.5 mm`](./parts/dc-power-plug.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/charging-port.jpg?raw=true)](./parts/dc-power-plug.md)  | [`DSN-VC288, panel mount, 4-30 VDC, 10A (50A with shunt resistor), voltmeter ammeter`](./parts/dsn-vc288.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/dsn-vc288.jpg?raw=true)](./parts/dsn-vc288.md)  | [`XL4015: 8 - 36 VDC -> 1.25 - 32 VDC, 5A`](./parts/XL4015.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/XL4015.png?raw=true)](./parts/XL4015.md)  | [`double-sided PCB, 9 cm x 7 cm`](./parts/PCB-double-9x7.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/PCB-double-9x7.jpeg?raw=true)](./parts/PCB-double-9x7.md) 10 x 15 holes | [`nuts, bolts, and spacers`](./parts/nuts-bolts-spacers.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/nuts-bolts-spacers.jpg?raw=true)](./parts/nuts-bolts-spacers.md) M3: (7 x bolt + 7 x nut + 1 x 5 mm spacer + 7 x 15 mm spacer + 2 x 25 mm spacer + 3 x 35 mm spacer) | [`pin headers`](./parts/pin-headers.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/pin-headers.jpg?raw=true)](./parts/pin-headers.md) 2 x (2 x 3, 90 degree) | [`plexiglass, 2 mm or 2.5 mm thickness`](./parts/plexiglass.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/plexiglass.jpg?raw=true)](./parts/plexiglass.md) 2 x 88 cm x 88 cm | [`white terminal`](./parts/white-terminal.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/white-terminal.jpg?raw=true)](./parts/white-terminal.md) 2 x |

1. [DC power plug, 5.5 mm](./parts/dc-power-plug.md).
1. [DSN-VC288, panel mount, 4-30 VDC, 10A (50A with shunt resistor), voltmeter ammeter](./parts/dsn-vc288.md).
1. [XL4015: 8 - 36 VDC -> 1.25 - 32 VDC, 5A](./parts/XL4015.md).
1. [double-sided PCB, 9 cm x 7 cm](./parts/PCB-double-9x7.md): 10 x 15 holes.
1. [nuts, bolts, and spacers](./parts/nuts-bolts-spacers.md): M3: (7 x bolt + 7 x nut + 1 x 5 mm spacer + 7 x 15 mm spacer + 2 x 25 mm spacer + 3 x 35 mm spacer).
1. [pin headers](./parts/pin-headers.md): 2 x (2 x 3, 90 degree).
1. [plexiglass, 2 mm or 2.5 mm thickness](./parts/plexiglass.md): 2 x 88 cm x 88 cm.
1. [white terminal](./parts/white-terminal.md): 2 x.
